@@ -1,3 +1,24 @@
+# -*- coding: utf-8 -*-
+#
+#  __init__.py - commander
+#
+#  Copyright (C) 2010 - Jesse van den Kieboom
+#
+#  This program is free software; you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation; either version 2 of the License, or
+#  (at your option) any later version.
+#
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#
+#  You should have received a copy of the GNU General Public License
+#  along with this program; if not, write to the Free Software
+#  Foundation, Inc., 59 Temple Place, Suite 330,
+#  Boston, MA 02111-1307, USA.
+
 import os
 import gio
 import sys
@@ -66,11 +87,14 @@ class Commands(Singleton):
 			self.retval = None
 
 		def autocomplete_func(self):
-			if retval == result.Result.PROMPT:
-				return retval.autocomplete
+			if self.retval == result.Result.PROMPT:
+				return self.retval.autocomplete
 			else:
 				return {}
 
+		def args(self):
+			return [], True
+
 	class State:
 		def __init__(self):
 			self.clear()
@@ -383,7 +407,7 @@ class Commands(Singleton):
 			mod.reload()
 		except Exception, e:
 			# Reload failed, we remove the module
-			print 'Failed to reload module:', e
+			print 'Failed to reload module (%s):' % (mod.name,), e
 
 			self._modules.remove(mod)
 			return
